##  Introduction to Organizations
Organizations represent the users of applications and are intended for modeling who is using certain applications. The organization fact sheet type is an essential element to represent your organization’s business architecture in SAP LeanIX, and you can model different dimensions to create hierarchical structures. It allows you to get some basic views to understand synergies and gaps in the application landscape across different parts of the organization.
By structuring organizations hierarchically, you can visualize which parts of your business use specific applications. This helps identify overlaps, gaps, and opportunities for synergy across your application landscape.
To learn how to model organizations, see [Organization Modeling Guidelines](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model organizations. This includes best practices and applicable use cases, and common antipatterns.").
